@@ -1,89 +1,36 @@
 #!/usr/bin/env bash
 
 #############################################################################
-## 
-##   XML documenting files to plain text conversion script 
-##   Last updated on July 18, 2022
-## 
-##   This file is part of Logtalk <https://logtalk.org/>  
+##
+##   XML documenting files to plain text conversion script
+##   Last updated on March 23, 2025
+##
+##   This file is part of Logtalk <https://logtalk.org/>
 ##   SPDX-FileCopyrightText: 1998-2025 Paulo Moura <pmoura@logtalk.org>
 ##   SPDX-License-Identifier: Apache-2.0
-##   
+##
 ##   Licensed under the Apache License, Version 2.0 (the "License");
 ##   you may not use this file except in compliance with the License.
 ##   You may obtain a copy of the License at
-##   
+##
 ##       http://www.apache.org/licenses/LICENSE-2.0
-##   
+##
 ##   Unless required by applicable law or agreed to in writing, software
 ##   distributed under the License is distributed on an "AS IS" BASIS,
 ##   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 ##   See the License for the specific language governing permissions and
 ##   limitations under the License.
-## 
+##
 #############################################################################
 
 
 print_version() {
-	echo "$(basename "$0") 2.3"
+	echo "$(basename "$0") 2.6"
 	exit 0
 }
 
-if ! [ "$LOGTALKHOME" ]; then
-	echo "The environment variable LOGTALKHOME should be defined first, pointing"
-	echo "to your Logtalk installation directory!"
-	echo "Trying the default locations for the Logtalk installation..."
-	if [ -d "/usr/local/share/logtalk" ]; then
-		LOGTALKHOME=/usr/local/share/logtalk
-		echo "... using Logtalk installation found at /usr/local/share/logtalk"
-	elif [ -d "/usr/share/logtalk" ]; then
-		LOGTALKHOME=/usr/share/logtalk
-		echo "... using Logtalk installation found at /usr/share/logtalk"
-	elif [ -d "/opt/local/share/logtalk" ]; then
-		LOGTALKHOME=/opt/local/share/logtalk
-		echo "... using Logtalk installation found at /opt/local/share/logtalk"
-	elif [ -d "/opt/share/logtalk" ]; then
-		LOGTALKHOME=/opt/share/logtalk
-		echo "... using Logtalk installation found at /opt/share/logtalk"
-	elif [ -d "$HOME/share/logtalk" ]; then
-		LOGTALKHOME="$HOME/share/logtalk"
-		echo "... using Logtalk installation found at $HOME/share/logtalk"
-	elif [ -f "$( cd "$( dirname "$0" )" && pwd )/../core/core.pl" ]; then
-		LOGTALKHOME="$( cd "$( dirname "$0" )" && pwd )/.."
-		echo "... using Logtalk installation found at $( cd "$( dirname "$0" )" && pwd )/.."
-	else
-		echo "... unable to locate Logtalk installation directory!" >&2
-		echo
-		exit 1
-	fi
-	echo
-elif ! [ -d "$LOGTALKHOME" ]; then
-	echo "The environment variable LOGTALKHOME points to a non-existing directory!" >&2
-	echo "Its current value is: $LOGTALKHOME" >&2
-	echo "The variable must be set to your Logtalk installation directory!" >&2
-	echo
-	exit 1
-fi
-export LOGTALKHOME
-
-if ! [ "$LOGTALKUSER" ]; then
-	echo "The environment variable LOGTALKUSER should be defined first, pointing"
-	echo "to your Logtalk user directory!"
-	echo "Trying the default location for the Logtalk user directory..."
-	export LOGTALKUSER=$HOME/logtalk
-	if [ -d "$LOGTALKUSER" ]; then
-		echo "... using Logtalk user directory found at $LOGTALKUSER"
-	else
-		echo "... Logtalk user directory not found at default location. Creating a new"
-		echo "Logtalk user directory by running the \"logtalk_user_setup\" shell script:"
-		logtalk_user_setup
-	fi
-elif ! [ -d "$LOGTALKUSER" ]; then
-	echo "Cannot find \$LOGTALKUSER directory! Creating a new Logtalk user directory"
-	echo "by running the \"logtalk_user_setup\" shell script:"
-	logtalk_user_setup
-fi
-echo
+source "$(dirname "$0")/logtalk_setup_env.sh"
+setup_logtalk_env || exit 1
 
 entity_xslt="$LOGTALKUSER/tools/lgtdoc/xml/logtalk_entity_to_txt.xsl"
 index_xslt="$LOGTALKUSER/tools/lgtdoc/xml/logtalk_index_to_txt.xsl"
@@ -94,9 +41,8 @@ processor=xsltproc
 
 directory="."
 
-usage_help()
-{
-	echo 
+usage_help() {
+	echo
 	echo "This script converts all Logtalk XML documenting files in the"
 	echo "current directory to plain text files"
 	echo
@@ -113,14 +59,13 @@ usage_help()
 	echo
 }
 
-while getopts "vd:p:h" Option
-do
-	case $Option in
+while getopts "vd:p:h" option; do
+	case $option in
 		v) print_version;;
 		d) d_arg="$OPTARG";;
 		p) p_arg="$OPTARG";;
-		h) usage_help; exit;;
-		*) usage_help; exit;;
+		h) usage_help; exit 0;;
+		*) usage_help; exit 1;;
 	esac
 done
 
@@ -140,6 +85,11 @@ elif [ "$p_arg" != "" ] ; then
 	processor=$p_arg
 fi
 
+if ! [ -x "$(command -v $processor)" ] ; then
+	echo "Error: Cannot find the $processor command-line tool!" >&2
+	exit 1
+fi
+
 if ! [ -e "./logtalk_entity.dtd" ] ; then
 	cp "$LOGTALKHOME"/tools/lgtdoc/xml/logtalk_entity.dtd .
 fi
